@@ -1,11 +1,9 @@
 use std::io;
 
-use thiserror::Error;
-
 /// CoNLL-U IO error.
-#[derive(Debug, Error)]
+#[derive(Debug, thiserror::Error)]
 #[non_exhaustive]
-pub enum IOError {
+pub enum Error {
     /// Error in file IO.
     #[error("error reading treebank")]
     IO(#[from] io::Error),
@@ -16,9 +14,13 @@ pub enum IOError {
 }
 
 /// CoNLL-U parsing errors.
-#[derive(Debug, Error, Eq, PartialEq)]
+#[derive(Debug, thiserror::Error, Eq, PartialEq)]
 #[non_exhaustive]
 pub enum ParseError {
+    /// Error construction the graph.
+    #[error(transparent)]
+    Parse(#[from] udgraph::Error),
+
     /// The form is missing in the CoNLL-U data.
     #[error("form field is missing")]
     MissingFormField,
