@@ -1,7 +1,7 @@
 //! Traits to read/write `udgraph` graphs from CoNLL-U format.
 
 mod error;
-pub use crate::error::{IOError, ParseError};
+pub use crate::error::{Error, ParseError};
 
 pub mod io;
 
